@@ -19,10 +19,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/** 
+ * Extensions to GPGME for not yet or 'won't support' features.
+ */
+
 #ifndef __SEAHORSE_GPGMEX_H__
 #define __SEAHORSE_GPGMEX_H__
 
+#include "config.h"
 #include <gpgme.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 /* -----------------------------------------------------------------------------
  * ERROR HANDLING 
@@ -32,6 +38,22 @@
 #define GPG_OK              (gpgme_error (GPG_ERR_NO_ERROR))
 #define GPG_E(e)            (gpgme_error (e))
 
+/* -----------------------------------------------------------------------------
+ * DATA ALLOCATION
+ */
+ 
+/* 
+ * GTK/Glib use a model where if allocation fails, the program exits. These 
+ * helper functions extend certain GPGME calls to provide the same behavior.
+ */
+ 
+gpgme_data_t        gpgmex_data_new          ();
+
+void                gpgmex_data_release      (gpgme_data_t data);
+
+gpgme_data_t        gpgmex_data_new_from_mem (const char *buffer, size_t size,
+                                              gboolean copy);
+
 /* -----------------------------------------------------------------------------
  * KEY ALLOCATION
  */
@@ -51,6 +73,14 @@ enum {
     GPGMEX_KEY_DISABLED = 0x02
 };
 
+/* A photo id from a key */
+typedef struct _gpgmex_photo_id {
+    struct _gpgmex_photo_id *next;
+    
+    guint uid;            /* The actual uid used with gpgpme_op_edit */
+    GdkPixbuf *photo;     /* The photo itself */
+} *gpgmex_photo_id_t;
+    
 gpgme_key_t gpgmex_key_alloc         ();
 
 void        gpgmex_key_add_subkey    (gpgme_key_t key,
@@ -77,6 +107,14 @@ void        gpgmex_key_ref           (gpgme_key_t key);
 
 void        gpgmex_key_unref         (gpgme_key_t key);
 
+gpgmex_photo_id_t 
+            gpgmex_photo_id_alloc    (guint uid);
+            
+void        gpgmex_photo_id_free     (gpgmex_photo_id_t photoid);
+
+void        gpgmex_photo_id_free_all (gpgmex_photo_id_t photoid);
+
+
 /* -----------------------------------------------------------------------------
  * EXTRA FUNCTIONALITY
  */
@@ -85,4 +123,8 @@ gpgme_error_t gpgmex_op_export_secret  (gpgme_ctx_t ctx,
                                         const char *pattern,
                                         gpgme_data_t keydata);
 
+gpgme_error_t gpgmex_op_num_uids       (gpgme_ctx_t ctx, 
+                                        const char *pattern,
+                                        guint *number);
+ 
 #endif /* __SEAHORSE_GPGMEX_H__ */
