@@ -18,7 +18,7 @@
  * 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-
+#include <config.h>
 #include <gnome.h>
 
 #include "seahorse-gpgmex.h"
@@ -107,6 +107,7 @@ static SeahorseValidity
 calc_validity (SeahorsePGPKey *pkey)
 {
     g_return_val_if_fail (pkey->pubkey, SEAHORSE_VALIDITY_UNKNOWN);
+    g_return_val_if_fail (pkey->pubkey->uids, SEAHORSE_VALIDITY_UNKNOWN);
 
     if (pkey->pubkey->revoked)
         return SEAHORSE_VALIDITY_REVOKED;
@@ -177,7 +178,8 @@ changed_key (SeahorsePGPKey *pkey)
         if (!pkey->pubkey->disabled && !pkey->pubkey->expired && 
             !pkey->pubkey->revoked && !pkey->pubkey->invalid)
         {
-            skey->flags |= SKEY_FLAG_IS_VALID;
+            if (calc_validity (pkey) >= SEAHORSE_VALIDITY_MARGINAL)
+                skey->flags |= SKEY_FLAG_IS_VALID;
             if (pkey->pubkey->can_encrypt)
                 skey->flags |= SKEY_FLAG_CAN_ENCRYPT;
             if (pkey->seckey && pkey->pubkey->can_sign)
@@ -269,7 +271,9 @@ seahorse_pgp_key_get_name_markup (SeahorseKey *skey, guint index)
     SeahorsePGPKey *pkey;
     gpgme_user_id_t uid;
     gchar *email, *name, *comment, *ret;
-    
+    gboolean strike = FALSE;
+    guint flags;
+
     g_assert (SEAHORSE_IS_PGP_KEY (skey));
     pkey = SEAHORSE_PGP_KEY (skey);
 
@@ -279,15 +283,23 @@ seahorse_pgp_key_get_name_markup (SeahorseKey *skey, guint index)
     name = convert_string (uid->name, TRUE);
     email = convert_string (uid->email, TRUE);
     comment = convert_string (uid->comment, TRUE);
+
+    flags = seahorse_key_get_flags (skey);
+    if (uid->revoked || flags & CRYPTUI_FLAG_EXPIRED || 
+        flags & CRYPTUI_FLAG_REVOKED || flags & CRYPTUI_FLAG_DISABLED)
+        strike = TRUE;
     
-    ret = g_strconcat (name, 
+    ret = g_strconcat (strike ? "<span strikethrough='true'>" : "",
+            name,
             "<span foreground='#555555' size='small' rise='0'>",
             email && email[0] ? "  " : "",
             email && email[0] ? email : "",
             comment && comment[0] ? "  '" : "",
             comment && comment[0] ? comment : "",
             comment && comment[0] ? "'" : "",
-            "</span>", NULL);
+            "</span>", 
+            strike ? "</span>" : "",
+            NULL);
     
     g_free (name);
     g_free (comment);
