@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
  
+#include <config.h>
 #include <gnome.h>
  
 #include "seahorse-gpgmex.h"
@@ -74,7 +75,6 @@ expires_toggled (GtkWidget *widget, SeahorseWidget *swidget)
 {
 	GtkWidget *expire;
 	GtkWidget *cal;
-	gboolean toggled;
 	
 	expire = glade_xml_get_widget (swidget->xml, "expire");
 	cal = glade_xml_get_widget (swidget->xml, "calendar");
