@@ -23,6 +23,7 @@
 
 /* TODO: Make sure to free when getting text from seahorse_pgp_key_* */
 
+#include "config.h"
 #include <gnome.h>
 #include <time.h>
 
@@ -70,7 +71,24 @@ sensitive_glade_widget (SeahorseWidget *swidget, const gchar *name, gboolean sen
     GtkWidget *widget = glade_xml_get_widget (swidget->xml, name);
     if (widget)
         gtk_widget_set_sensitive (widget, sens);
-}    
+}
+
+static void
+printf_glade_widget (SeahorseWidget *swidget, const gchar *name, const gchar *str)
+{
+    GtkWidget *widget;
+    const gchar *label;
+    gchar *text;
+    
+    widget = glade_xml_get_widget (swidget->xml, name);
+    if (!widget)
+        return; 
+    
+    label = gtk_button_get_label (GTK_BUTTON (widget));
+    text = g_strdup_printf (label, str);
+    gtk_button_set_label (GTK_BUTTON (widget), text);
+    g_free (text);
+}
 
 static gint
 get_selected_row (SeahorseWidget *swidget, const gchar *gladeid, guint column)
@@ -1006,7 +1024,7 @@ details_export_button_clicked (GtkWidget *widget, SeahorseWidget *swidget)
         gpgmex_data_release (data);
         
         if (!seahorse_operation_is_successful (op))
-            seahorse_operation_steal_error (op, &err);
+            seahorse_operation_copy_error (op, &err);
     }
     
     if (err)
@@ -1204,7 +1222,9 @@ do_details (SeahorseWidget *swidget)
 
     widget = glade_xml_get_widget (swidget->xml, "details-expires-label");
     if (widget) {
-        if (subkey->expires == 0)
+        if (seahorse_key_get_location (skey) == SKEY_LOC_REMOTE)
+            fp_label = NULL;
+        else if (subkey->expires == 0)
             fp_label = g_strdup (_("Never"));
         else
             fp_label = seahorse_util_get_date_string (subkey->expires);
@@ -1490,7 +1510,8 @@ do_trust_signals (SeahorseWidget *swidget)
 {
     SeahorseKey *skey;
     SeahorseKeyEType etype;
-
+    gchar *user;
+    
     skey = SEAHORSE_KEY_WIDGET (swidget)->skey;
     etype = seahorse_key_get_etype (skey);
     
@@ -1505,14 +1526,24 @@ do_trust_signals (SeahorseWidget *swidget)
     /* TODO: Hookup revoke handler */
     
     if (etype == SKEY_PUBLIC ) {
+        
         show_glade_widget (swidget, "signatures-revoke-button", FALSE);
         show_glade_widget (swidget, "signatures-delete-button", FALSE);
         show_glade_widget (swidget, "signatures-empty-label", FALSE);
+        
+        /* Fill in trust labels with name .This only happens once, so it sits here. */
+        user = seahorse_pgp_key_get_userid_name (SEAHORSE_PGP_KEY (skey), 0);
+        printf_glade_widget (swidget, "trust-marginal-check", user);
+        printf_glade_widget (swidget, "trust-complete-check", user);
+        g_free (user);
+        
     } else {
+        
         glade_xml_signal_connect_data (swidget->xml, "signatures_revoke_button_clicked",
                                        G_CALLBACK (signatures_revoke_button_clicked), swidget);
         glade_xml_signal_connect_data (swidget->xml, "signatures_delete_button_clicked",
                                        G_CALLBACK (signatures_delete_button_clicked), swidget);
+        
     }
 
     glade_xml_signal_connect_data (swidget->xml, "trust_marginal_toggled",
@@ -1853,7 +1884,7 @@ seahorse_key_properties_new (SeahorsePGPKey *pkey)
     /* Don't trigger the import of remote keys if possible */
     if (!remote) {
         /* This causes the key source to get any specific info about the key */
-        seahorse_key_source_load_sync (sksrc, SKSRC_LOAD_KEY, seahorse_key_get_keyid (skey), NULL);
+        seahorse_key_source_load_sync (sksrc, seahorse_key_get_keyid (skey));
         skey = seahorse_context_get_key (SCTX_APP(), sksrc, seahorse_key_get_keyid (skey));
         g_return_if_fail (skey != NULL);
     }
